summaryrefslogtreecommitdiff
path: root/src/eval/value.rs
diff options
context:
space:
mode:
Diffstat (limited to 'src/eval/value.rs')
-rw-r--r--src/eval/value.rs4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/eval/value.rs b/src/eval/value.rs
index b29d01f3..dda1c3e1 100644
--- a/src/eval/value.rs
+++ b/src/eval/value.rs
@@ -662,7 +662,7 @@ impl From<AnyValue> for Value {
}
}
/// Mark a type as a [`Value`].
///
/// Given a type `T`, this implements the following traits:
/// - [`Type`] for `T`,
@@ -684,7 +684,7 @@ impl From<AnyValue> for Value {
/// This would allow the type `FontFamily` to be cast from:
/// - a [`Value::Any`] variant already containing a `FontFamily`,
/// - a string, producing a named font family.
-macro_rules! value {
+macro_rules! castable {
($type:ty:
$type_name:literal
$(, $pattern:pat => $out:expr)*
@@ -662,7 +662,7 @@ impl From<AnyValue> for Value {
}
}
-/// Mark a type as a [`Value`].
+/// Make a type castable from a value.
///
/// Given a type `T`, this implements the following traits: